###
# Licensed Materials - Property of IBM Corp.
# @product.name.full@
# (c) Copyright IBM Corporation 2003, 2014. All Rights Reserved.
# 
# U.S. Government Users Restricted Rights - Use, duplication or disclosure restricted by
# GSA ADP Schedule Contract with IBM Corp.
# 
# Filename: confdiscover.py
# 
# 
###

from org.codehaus.jettison.json import JSONArray;
import sys;
import os;

import javaos  # @UnresolvedImport
from java.lang import Throwable
import traceback
if javaos._osType == 'posix' and java.lang.System.getProperty('os.name').startswith('Windows'):  # @UndefinedVariable
  sys.registry.setProperty('python.os', 'nt');
  reload(javaos);

sys.modules['AdminConfig'] = AdminConfig # @UndefinedVariable
sys.modules['AdminControl'] = AdminControl # @UndefinedVariable
sys.modules['AdminApp'] = AdminApp # @UndefinedVariable
sys.modules['AdminTask'] = AdminTask # @UndefinedVariable

configurationTypes = {};
stack = [];

def mainmethod():
  pihelper = PluginInputHelper.PluginInputHelper(sys.argv[0]);
  inputProps = pihelper.getInputProperties();

  logDir = pihelper.getLogDirectory();
  logFile = open("%s/debugLog.txt" % logDir.getAbsolutePath(),'w');
  redoFile = open("%s/redoLog.txt" % logDir.getAbsolutePath(),'w');
  Log.setLogFile(logFile);
  Log.setRedoFile(redoFile);

  resourceJSONObject = pihelper.getFullResourceConfiguration();
  configurationTypesInput = inputProps.getProperty("configurationTypes");

  adminConfigTypes = Util.getAdminConfigTypes();

  if configurationTypesInput is not None and len(configurationTypesInput) > 0:
    for line in configurationTypesInput.splitlines():
      line = line.strip();
      if len(line) > 0:
        if line in adminConfigTypes:
          configurationTypes[line] = line;

  Util.setConfigurationTypes(configurationTypes);

  roleName = None;
  containmentpath = "/Cell:" + Util.getCell();
  if resourceJSONObject is not None:
    roleName = resourceJSONObject.getString("roleName");
    roleName = Util.roleNameToType(roleName);
    containmentpath = Util.findContainmentPath(resourceJSONObject);
  else:
    roleName = "Cell";

  topObjectDir = Util.findObjectDir(roleName, objectsDir);
  finalResources = JSONArray();
  respath = "/"

  index = containmentpath.rindex('/',0,len(containmentpath)-2)+1;
  parentcontainmentpath = containmentpath[0:index];
  if parentcontainmentpath == "/":
    parentcontainmentpath="";
  Log.debug("Initial Containment path %s" % containmentpath);
  if containmentpath != "":
    objid = Util.getid(containmentpath);
  else:
    objid = Util.getid("/Cell:/");
  Log.debug("Fin Containment path %s" % containmentpath);
  Log.debug("Parent Containment path %s" % parentcontainmentpath);
  Log.debug(roleName);
  Log.debug(respath)
  Log.debug(objid)
  stack = [];
  curresources = Util.exportObjectToResources(stack, objectsDir, topObjectDir, objid, respath, parentcontainmentpath, roleName);
  if curresources is not None:
    for y in range(curresources.length()):
      finalResources.put(curresources.get(y));

  applicableTypes = Util.getApplicableTypes("%s/plugin.xml" % PLUGIN_HOME);
  finalResources = Util.filterExportForTypes(finalResources, applicableTypes, configurationTypes);

  logFile.close();
  redoFile.close();
  print "\nConfiguration Discovery Complete.";
  print finalResources.toString(4);

PLUGIN_HOME=os.environ['PLUGIN_HOME'];
objectsDir = "%(plugHome)s%(fileSep)sobjects" % { 'plugHome': PLUGIN_HOME, 'fileSep': os.sep };
sys.path.insert(0,objectsDir);
Util = __import__("utilities.Util").Util;
MapHelper = __import__("utilities.MapHelper").MapHelper;
Log = __import__("WASConfLog.Log").Log;
PluginInputHelper = __import__("PluginInputHelper.PluginInputHelper").PluginInputHelper;

#we put everything possible in a method due to python global versus function scoping.
#repeatadly had issues with name collisions causing refactoring to pick up  a global variable with the same name as a local variable that was removed
try:
  mainmethod();
except: #except on anything, then check if its a java or python exception
  #why in the did jython not handle this gracefully....
  #print the stack here because websphere may decide to just swallow it
  actualExcept = sys.exc_info()[1];
  if isinstance(actualExcept, Throwable):
    actualExcept.printStackTrace();
  traceback.print_exc();
  raise actualExcept;
